==> open-xchange-gui-wizard-plugin_6.22.7.orig.tar.bz2: open-xchange-gui-wizard-plugin-6.22.7/com.openexchange.wizard/src/config.js <==
/**
 * 
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) 2004-2012 Open-Xchange, Inc.
 * Mail: info@open-xchange.com 
 * 
 * @author Ben Pahne <ben.pahne@open-xchange.com>
 * 
 */

var wizardTabPersonalData = true;
var wizardTabServices = true;
var wizardTabPublish = false;
var wizardTabMobility = true;
var wizardTabUpsell = false;

var wizardUpsellLayerTabUrl = "plugins/com.openexchange.wizard/upsell.html";

var wizzardMobilityNokia = true;
var wizzardMobilityWindowsMobile = true;
var wizzardMobilityiPhone = true;
var wizzardMobilityBlackBerry = true;
var wizzardMobilityWinPhone7 = true;
var wizzardMobilityAndroid2 = true;

// custom mail services
/*
var wizzardMailServices = { "Custom": {
			   transport_server: "smtp.custom.com",
			   transport_port:   "25",
			   mail_protocol:    "imap",
			   mail_server:      "imap.custom.com",
			   mail_port:        "993",
			   unified_inbox_enabled: false,
			   mail_secure:      true,
			   transport_secure: true,
			   transport_credentials: false,
			   tree:			 false,
			   spam_handler:     "NoSpamHandler"
			   // For POP3 accounts add these
			   //pop3_refresh_rate: 3,
               //pop3_expunge_on_quit: false,
               //pop3_delete_write_through: false,
               //pop3_storage: "mailaccount"
			   }
};
*/

// register a function to be executed when wizard is closed
/*register("OX_WIZARD_CLOSED", function() {
	//console.log("wizard closed");
}); */

// can be used to overwrite the mobility documentation
// by default the currently opened host is used
//var mobilityHost = "eas.example.com";

==> open-xchange-gui-wizard-plugin_6.22.10.orig.tar.bz2: open-xchange-gui-wizard-plugin-6.22.10/com.openexchange.wizard/src/config.js <==
/**
 * 
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) 2004-2012 Open-Xchange, Inc.
 * Mail: info@open-xchange.com 
 * 
 * @author Ben Pahne <ben.pahne@open-xchange.com>
 * 
 */

var wizardTabPersonalData = true;
var wizardTabServices = true;
var wizardTabPublish = false;
var wizardTabMobility = true;
var wizardTabUpsell = false;

var wizardUpsellLayerTabUrl = "plugins/com.openexchange.wizard/upsell.html";

var wizzardMobilityNokia = false;
var wizzardMobilityWindowsMobile = false;
var wizzardMobilityiPhone = true;
var wizzardMobilityBlackBerry = false;
var wizzardMobilityWinPhone7 = true;
var wizzardMobilityAndroid2 = true;

// custom mail services
/*
var wizzardMailServices = { "Custom": {
			   transport_server: "smtp.custom.com",
			   transport_port:   "25",
			   mail_protocol:    "imap",
			   mail_server:      "imap.custom.com",
			   mail_port:        "993",
			   unified_inbox_enabled: false,
			   mail_secure:      true,
			   transport_secure: true,
			   transport_credentials: false,
			   tree:			 false,
			   spam_handler:     "NoSpamHandler"
			   // For POP3 accounts add these
			   //pop3_refresh_rate: 3,
               //pop3_expunge_on_quit: false,
               //pop3_delete_write_through: false,
               //pop3_storage: "mailaccount"
			   }
};
*/

// register a function to be executed when wizard is closed
/*register("OX_WIZARD_CLOSED", function() {
	//console.log("wizard closed");
}); */

// can be used to overwrite the mobility documentation
// by default the currently opened host is used
//var mobilityHost = "eas.example.com";
